@@ -15,7 +15,7 @@ create_site_models_from_names <- function(site_model_names) {
   site_models <- list()
   for (i in seq_along(site_model_names)) {
     site_model_name <- site_model_names[i]
-    site_models[[i]] <- create_site_model_from_name(site_model_name) # nolint beautier function
+    site_models[[i]] <- beautier::create_site_model_from_name(site_model_name)
   }
   site_models
 }
