@@ -4,11 +4,11 @@
 #' @return the line number's index (which is 1 for the first line) if the
 #'   opening tag is found, else NA
 #' @author Richèl J.C. Bilderbeek
-#' @noRd
+#' @export
 find_last_xml_closing_tag_line <- function(
   lines,
   section
 ) {
   assertive::assert_is_a_string(section)
-  find_last_regex_line(lines, paste0("</", section, ">")) # nolint beautier function
+  beautier::find_last_regex_line(lines, paste0("</", section, ">"))
 }
