@@ -27,6 +27,6 @@
 has_mrca_prior <- function(
   inference_model
 ) {
-  check_inference_model(inference_model) # nolint beautier function
-  !is_one_na(inference_model$mrca_prior) # nolint beautier function
+  beautier::check_inference_model(inference_model)
+  !beautier::is_one_na(inference_model$mrca_prior)
 }
